@@ -1,7 +1,7 @@
 ;;; mana.scm: mana for uim.
 ;;; charset: EUC-JP
 ;;;
-;;; Copyright (c) 2003-2006 uim Project http://uim.freedesktop.org/
+;;; Copyright (c) 2003-2009 uim Project http://code.google.com/p/uim/
 ;;;
 ;;; All rights reserved.
 ;;;
@@ -95,7 +95,7 @@
                                   (else
                                     "")))
                               lst)))
-      (string-append "(" (string-join " " canonicalized) ")"))))
+      (string-append "(" (string-join canonicalized " ") ")"))))
 
 (define mana-set-string!
   (lambda (mc yomi yomi-len)
@@ -142,8 +142,9 @@
 	   (right-str (ustr-latter-seq raw-str))
 	   (left-str (ustr-former-seq raw-str)))
      (append left-str
-	     (if (not (null? residual-kana))
-		 (list pending))
+	     (if residual-kana
+		 (list pending)
+		 '())
 	     right-str))))
 
 (define mana-get-raw-candidate
@@ -157,8 +158,8 @@
 	   (preconv (ja-join-vu (string-to-list yomi)))
 	   (unconv (ja-join-vu (sublist
 				(string-to-list yomi)
-				(- (- yomi-len 1) (+ pos (- len 1)))
-				(- (- yomi-len 1) pos))))
+				(- yomi-len (+ pos len))
+				(- yomi-len pos))))
 	   (raw-str (reverse (mana-get-raw-str-seq mc))))
      (cond
       ((= cand-idx mana-candidate-type-hiragana)
@@ -174,7 +175,7 @@
 		     (len (length unconv)))
 		 (if start
 		     (mana-make-raw-string
-		      (reverse (sublist raw-str start (+ start (- len 1))))
+		      (reverse (sublist-rel raw-str start len))
 		      (if (or
 			   (= cand-idx mana-candidate-type-halfwidth-alnum)
 			   (= cand-idx
@@ -200,7 +201,7 @@
   (lambda (mc seg-idx)
     (let* ((segment-list (mana-context-segment-list mc))
            (segment (list-ref segment-list seg-idx)))
-      (if (not (mana-segment-candidate-list segment))
+      (if (null? (mana-segment-candidate-list segment))
           (mana-set-candidate-list! mc seg-idx))
       (mana-segment-nr-candidates segment))))
 
@@ -538,9 +539,9 @@
           (set! mana-lib-initialized? (mana-lib-init)))
       (mana-context-set-widgets! mc mana-widgets)
       (mana-context-set-rkc! mc rkc)
-      (mana-context-set-preconv-ustr! mc (ustr-new))
-      (mana-context-set-raw-ustr! mc (ustr-new))
-      (mana-context-set-segments! mc (ustr-new))
+      (mana-context-set-preconv-ustr! mc (ustr-new '()))
+      (mana-context-set-raw-ustr! mc (ustr-new '()))
+      (mana-context-set-segments! mc (ustr-new '()))
 
       ;; 2004-08-26 Takuro Ashie <ashie@homa.ne.jp>
       ;;   * I think load-kana-table should be marked as depracated.
@@ -624,7 +625,7 @@
 	      (ja-string-list-to-wide-alphabet 
 		(if upper?
 		    (map charcode->string
-			 (map char-upcase
+			 (map ichar-upcase
 			      (map string->charcode
 				   (string-to-list (car raw-str-list)))))
 		    (string-to-list (car raw-str-list))))
@@ -633,7 +634,7 @@
 	      (if upper?
 		  (string-list-concat
 		   (map charcode->string
-			(map char-upcase
+			(map ichar-upcase
 			     (map string->charcode
 				  (string-to-list (car raw-str-list))))))
 		  (car raw-str-list))
@@ -845,7 +846,7 @@
         (direct
           (im-commit mc direct))
 
-	;; spcae key => commit
+	;; space key => commit
 	((mana-space-key? key key-state)
 	 (if (mana-context-alnum mc)
 	     (im-commit mc (list-ref
@@ -870,7 +871,7 @@
 	     (let* ((key-str (charcode->string
 			      (if (= rule mana-input-rule-kana)
 				  key
-				  (to-lower-char key))))
+				  (ichar-downcase key))))
 		    (res (rk-push-key! rkc key-str)))
 	       (if res
 		   (begin
@@ -920,24 +921,27 @@
 	    (if (and lst
 	    	     (not (null? (cdr lst))))
 		(set! state (car (cdr lst)))
-		(set! state (mana-rotate-transposing-alnum-type
-			     (mana-context-transposing-type mc)
-			     (car rotate-list)))))
+		(if (not (null? rotate-list))
+		    (set! state (mana-rotate-transposing-alnum-type
+				 (mana-context-transposing-type mc)
+				 (car rotate-list))))))
 	  (begin
 	    (mana-context-set-transposing! mc #t)
 	    (set! state (car rotate-list))))
 
       (cond
-       ((or
-	 (= state mana-type-hiragana)
-	 (= state mana-type-katakana)
-	 (= state mana-type-halfkana))
+       ((and state
+	     (or
+	      (= state mana-type-hiragana)
+	      (= state mana-type-katakana)
+	      (= state mana-type-halfkana)))
 	(mana-context-set-transposing-type! mc state))
-       ((or
-	 (= state mana-type-halfwidth-alnum)
-	 (= state mana-candidate-type-upper-halfwidth-alnum)
-	 (= state mana-type-fullwidth-alnum)
-	 (= state mana-candidate-type-upper-fullwidth-alnum))
+       ((and state
+	     (or
+	      (= state mana-type-halfwidth-alnum)
+	      (= state mana-candidate-type-upper-halfwidth-alnum)
+	      (= state mana-type-fullwidth-alnum)
+	      (= state mana-candidate-type-upper-fullwidth-alnum)))
 	(if (not (= (mana-context-input-rule mc)
 		    mana-input-rule-kana))
 	    (mana-context-set-transposing-type! mc state)))
@@ -1011,8 +1015,8 @@
 	      (if (and
 		   (= (mana-context-input-rule mc) mana-input-rule-roma)
 		   (not (null? (ustr-former-seq preconv-str)))
-		   (not (char-printable?	;; check for kana
-			 (string->char
+		   (not (ichar-printable?	;; check for kana
+			 (string->ichar
 			  (car (last (ustr-former-seq preconv-str)))))))
 		  (ja-fix-deleted-raw-str-to-valid-roma! raw-str)))))
 
@@ -1164,13 +1168,13 @@
        (else
 	;; handle "n1" sequence as "1"
 	(if (and (not (mana-context-alnum mc))
-		 (not (alphabet-char? key))
+		 (not (ichar-alphabetic? key))
 		 (not (string-find
 		       (rk-expect rkc)
 		       (charcode->string
 			(if (= rule mana-input-rule-kana)
 			    key
-			    (to-lower-char key))))))
+			    (ichar-downcase key))))))
 	    (let ((pend (rk-pending rkc))
 		  (residual-kana (rk-push-key-last! rkc)))
 	      (if residual-kana
@@ -1197,7 +1201,7 @@
 	    (let* ((key-str (charcode->string 
 			     (if (= rule mana-input-rule-kana)
 				 key
-				 (to-lower-char key))))
+				 (ichar-downcase key))))
 		   (pend (rk-pending rkc))
 		   (res (rk-push-key! rkc key-str)))
 	      (if (and res
@@ -1238,8 +1242,8 @@
 
 (define mana-separator
   (lambda (mc)
-    (let ((attr (bit-or preedit-separator
-                        preedit-underline)))
+    (let ((attr (bitwise-ior preedit-separator
+			     preedit-underline)))
       (if mana-show-segment-separator?
           (cons attr mana-segment-separator)
           #f))))
@@ -1277,8 +1281,8 @@
       (append-map
         (lambda (seg-idx cand-idx)
           (let* ((attr (if (= seg-idx cur-seg)
-                           (bit-or preedit-reverse
-                                   preedit-cursor)
+                           (bitwise-ior preedit-reverse
+					preedit-cursor)
                            preedit-underline))
                  (cand (mana-get-nth-candidate mc seg-idx cand-idx))
                  (seg (list (cons attr cand))))
@@ -1404,7 +1408,7 @@
            (cur-page (if (= mana-nr-candidate-max 0)
                          0
                          (quotient n mana-nr-candidate-max)))
-           (pageidx (- (numeral-char->number numeralc) 1))
+           (pageidx (- (numeric-ichar->integer numeralc) 1))
            (compensated-pageidx (cond
                                   ((< pageidx 0) ; pressing key_0
                                    (+ pageidx 10))
@@ -1544,7 +1548,7 @@
        (mana-cancel-conv mc))
 
       ((and mana-select-candidate-by-numeral-key?
-            (numeral-char? key)
+            (ichar-numeric? key)
             (mana-context-candidate-window mc))
        (mana-move-candidate-in-page mc key))
 
@@ -1565,7 +1569,7 @@
 
 (define mana-press-key-handler
   (lambda (mc key key-state)
-    (if (control-char? key)
+    (if (ichar-control? key)
         (im-commit-raw mc)
         (if (mana-context-on mc)
             (if (mana-context-transposing mc)
@@ -1580,7 +1584,7 @@
 
 (define mana-release-key-handler
   (lambda (mc key key-state)
-    (if (or (control-char? key)
+    (if (or (ichar-control? key)
             (not (mana-context-on mc)))
         ;; don't discard key release event for apps
         (mana-commit-raw mc))))
