@@ -1,5 +1,5 @@
 ;;;
-;;; Copyright (c) 2003-2006 uim Project http://uim.freedesktop.org/
+;;; Copyright (c) 2003-2009 uim Project http://code.google.com/p/uim/
 ;;;
 ;;; All rights reserved.
 ;;;
@@ -27,7 +27,7 @@
 ;;; OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 ;;; SUCH DAMAGE.
 ;;;;
-;; 2006-11-13 version
+;; 2008-04-18 version
 
 ;;
 (require "generic.scm")
@@ -73,7 +73,7 @@
     ((("w" "1"))("")) (((" " "w" "1"))(""))
     ((("v" "1"))("")) (((" " "v" "1"))(""))
     ((("z" "1"))("")) (((" " "z" "1"))(""))
-    ((("\057" "1"))("")) (((" " "\057" "1"))(""))
+    ((("/" "1"))("")) (((" " "/" "1"))(""))
     ((("1" "2"))("")) (((" " "1" "2"))(""))
     ((("2" "2"))("")) (((" " "2" "2"))(""))
     ((("3" "2"))("")) (((" " "3" "2"))(""))
@@ -113,7 +113,7 @@
     ((("w" "2"))("")) (((" " "w" "2"))(""))
     ((("v" "2"))("")) (((" " "v" "2"))(""))
     ((("z" "2"))("")) (((" " "z" "2"))(""))
-    ((("\057" "2"))("")) (((" " "\057" "2"))(""))
+    ((("/" "2"))("")) (((" " "/" "2"))(""))
     ((("1" "3"))("")) (((" " "1" "3"))(""))
     ((("2" "3"))("")) (((" " "2" "3"))(""))
     ((("3" "3"))("")) (((" " "3" "3"))(""))
@@ -152,8 +152,8 @@
     ((("m" "3"))("")) (((" " "m" "3"))(""))
     ((("w" "3"))("")) (((" " "w" "3"))(""))
     ((("v" "3"))("")) (((" " "v" "3"))(""))
-    ((("z" "3"))("Ĭ")) (((" " "z" "3"))(""))
-    ((("\057" "3"))("")) (((" " "\057" "3"))(""))
+    ((("z" "3"))("")) (((" " "z" "3"))(""))
+    ((("/" "3"))("")) (((" " "/" "3"))(""))
     ((("1" "4"))("")) (((" " "1" "4"))(""))
     ((("2" "4"))("")) (((" " "2" "4"))(""))
     ((("3" "4"))("")) (((" " "3" "4"))(""))
@@ -193,17 +193,17 @@
     ((("w" "4"))("")) (((" " "w" "4"))(""))
     ((("v" "4"))("")) (((" " "v" "4"))(""))
     ((("z" "4"))("Ĭ")) (((" " "z" "4"))(""))
-    ((("\057" "4"))(""))  (((" " "\057" "4"))(""))
+    ((("/" "4"))("")) (((" " "/" "4"))(""))
     ((("1" "5"))("")) (((" " "1" "5"))(""))
-    ((("2" "5"))("")) (((" " "1" "5"))(""))
-    ((("3" "5"))("")) (((" " "1" "5"))(""))
-    ((("4" "5"))("")) (((" " "1" "5"))(""))
-    ((("5" "5"))("")) (((" " "1" "5"))(""))
-    ((("6" "5"))("")) (((" " "1" "5"))(""))
-    ((("7" "5"))("")) (((" " "1" "5"))(""))
-    ((("8" "5"))("")) (((" " "1" "5"))(""))
-    ((("9" "5"))("")) (((" " "1" "5"))(""))
-    ((("0" "5"))("")) (((" " "1" "5"))(""))
+    ((("2" "5"))("")) (((" " "2" "5"))(""))
+    ((("3" "5"))("")) (((" " "3" "5"))(""))
+    ((("4" "5"))("")) (((" " "4" "5"))(""))
+    ((("5" "5"))("")) (((" " "5" "5"))(""))
+    ((("6" "5"))("")) (((" " "6" "5"))(""))
+    ((("7" "5"))("")) (((" " "7" "5"))(""))
+    ((("8" "5"))("")) (((" " "8" "5"))(""))
+    ((("9" "5"))("")) (((" " "9" "5"))(""))
+    ((("0" "5"))("")) (((" " "0" "5"))(""))
     ((("," "5"))("")) (((" " "," "5"))(""))
     ((("." "5"))("")) (((" " "." "5"))(""))
     ((("p" "5"))("")) (((" " "p" "5"))(""))
@@ -233,87 +233,87 @@
     ((("w" "5"))("˿")) (((" " "w" "5"))(""))
     ((("v" "5"))("")) (((" " "v" "5"))(""))
     ((("z" "5"))("")) (((" " "z" "5"))(""))
-    ((("\057" "5"))("")) (((" " "\057" "5"))(""))
-    ((("1" "6"))("")) (((" ""1" "6"))(""))
-    ((("2" "6"))("")) (((" ""1" "6"))(""))
-    ((("3" "6"))("")) (((" ""1" "6"))(""))
-    ((("4" "6"))("")) (((" ""1" "6"))(""))
-    ((("5" "6"))("")) (((" ""1" "6"))(""))
-    ((("6" "6"))("")) (((" ""1" "6"))(""))
-    ((("7" "6"))("")) (((" ""1" "6"))(""))
-    ((("8" "6"))("")) (((" ""1" "6"))(""))
-    ((("9" "6"))("")) (((" ""1" "6"))(""))
-    ((("0" "6"))("")) (((" ""1" "6"))(""))
-    ((("," "6"))("")) (((" ""1" "6"))(""))
-    ((("." "6"))("")) (((" ""1" "6"))("é"))
-    ((("p" "6"))("")) (((" ""1" "6"))(""))
-    ((("y" "6"))("©")) (((" ""1" "6"))(""))
-    ((("f" "6"))("")) (((" ""1" "6"))(""))
-    ((("g" "6"))("")) (((" ""1" "6"))(""))
-    ((("c" "6"))("")) (((" ""1" "6"))(""))
-    ((("r" "6"))("")) (((" ""1" "6"))(""))
-    ((("l" "6"))("Ƹ")) (((" ""1" "6"))(""))
-    ((("a" "6"))("")) (((" ""1" "6"))(""))
-    ((("o" "6"))("")) (((" ""1" "6"))(""))
-    ((("e" "6"))("")) (((" ""1" "6"))(""))
-    ((("u" "6"))("")) (((" ""1" "6"))(""))
-    ((("i" "6"))("")) (((" ""1" "6"))(""))
-    ((("d" "6"))("")) (((" ""1" "6"))(""))
-    ((("h" "6"))("")) (((" ""1" "6"))(""))
-    ((("t" "6"))("")) (((" ""1" "6"))(""))
-    ((("n" "6"))("")) (((" ""1" "6"))("Ŀ"))
-    ((("s" "6"))("")) (((" ""1" "6"))(""))
-    (((";" "6"))("Ȫ")) (((" ""1" "6"))(""))
-    ((("q" "6"))("")) (((" ""1" "6"))(""))
-    ((("j" "6"))("")) (((" ""1" "6"))(""))
-    ((("k" "6"))("ū")) (((" ""1" "6"))(""))
-    ((("x" "6"))("")) (((" ""1" "6"))(""))
-    ((("b" "6"))("")) (((" ""1" "6"))(""))
-    ((("m" "6"))("")) (((" ""1" "6"))(""))
-    ((("w" "6"))("")) (((" ""1" "6"))(""))
-    ((("v" "6"))("")) (((" ""1" "6"))(""))
-    ((("z" "6"))("")) (((" ""1" "6"))(""))
-    ((("\057" "6"))("")) (((" ""1" "6"))(""))
-    ((("1" "7"))("")) (((" ""1" "7"))(""))
-    ((("2" "7"))("")) (((" ""2" "7"))(""))
-    ((("3" "7"))("")) (((" ""3" "7"))(""))
-    ((("4" "7"))("")) (((" ""4" "7"))(""))
-    ((("5" "7"))("")) (((" ""5" "7"))(""))
-    ((("6" "7"))("")) (((" ""6" "7"))(""))
-    ((("7" "7"))("")) (((" ""7" "7"))(""))
-    ((("8" "7"))("")) (((" ""8" "7"))(""))
-    ((("9" "7"))("")) (((" ""9" "7"))(""))
-    ((("0" "7"))("")) (((" ""0" "7"))(""))
-    ((("," "7"))("»")) (((" ""," "7"))(""))
-    ((("." "7"))("ɶ")) (((" ""." "7"))(""))
-    ((("p" "7"))("")) (((" ""p" "7"))(""))
-    ((("y" "7"))("")) (((" ""y" "7"))(""))
-    ((("f" "7"))("")) (((" ""f" "7"))(""))
-    ((("g" "7"))("æ")) (((" ""g" "7"))(""))
-    ((("c" "7"))("")) (((" ""c" "7"))(""))
-    ((("r" "7"))("")) (((" ""r" "7"))(""))
-    ((("l" "7"))("º")) (((" ""l" "7"))(""))
-    ((("a" "7"))("")) (((" ""a" "7"))(""))
-    ((("o" "7"))("")) (((" ""o" "7"))(""))
-    ((("e" "7"))("͹")) (((" ""e" "7"))(""))
-    ((("u" "7"))("")) (((" ""u" "7"))(""))
-    ((("i" "7"))("")) (((" ""i" "7"))(""))
-    ((("d" "7"))("")) (((" ""d" "7"))(""))
-    ((("h" "7"))("")) (((" ""h" "7"))(""))
-    ((("t" "7"))("")) (((" ""t" "7"))(""))
-    ((("n" "7"))("")) (((" ""n" "7"))(""))
-    ((("s" "7"))("")) (((" ""s" "7"))(""))
-    (((";" "7"))("")) (((" "";" "7"))(""))
-    ((("q" "7"))("ü")) (((" ""q" "7"))(""))
-    ((("j" "7"))("")) (((" ""j" "7"))(""))
-    ((("k" "7"))("")) (((" ""k" "7"))(""))
-    ((("x" "7"))("")) (((" ""x" "7"))(""))
-    ((("b" "7"))("")) (((" ""b" "7"))(""))
-    ((("m" "7"))("")) (((" ""m" "7"))(""))
-    ((("w" "7"))("")) (((" ""w" "7"))(""))
-    ((("v" "7"))("")) (((" ""v" "7"))(""))
-    ((("z" "7"))("")) (((" ""z" "7"))(""))
-    ((("\057" "7"))("")) (((" ""\057" "7"))("м"))
+    ((("/" "5"))("")) (((" " "/" "5"))(""))
+    ((("1" "6"))("")) (((" " "1" "6"))(""))
+    ((("2" "6"))("")) (((" " "2" "6"))(""))
+    ((("3" "6"))("")) (((" " "3" "6"))(""))
+    ((("4" "6"))("")) (((" " "4" "6"))(""))
+    ((("5" "6"))("")) (((" " "5" "6"))(""))
+    ((("6" "6"))("")) (((" " "6" "6"))(""))
+    ((("7" "6"))("")) (((" " "7" "6"))(""))
+    ((("8" "6"))("")) (((" " "8" "6"))(""))
+    ((("9" "6"))("")) (((" " "9" "6"))(""))
+    ((("0" "6"))("")) (((" " "0" "6"))(""))
+    ((("," "6"))("")) (((" " "," "6"))(""))
+    ((("." "6"))("")) (((" " "." "6"))("é"))
+    ((("p" "6"))("")) (((" " "p" "6"))(""))
+    ((("y" "6"))("©")) (((" " "y" "6"))(""))
+    ((("f" "6"))("")) (((" " "f" "6"))(""))
+    ((("g" "6"))("")) (((" " "g" "6"))(""))
+    ((("c" "6"))("")) (((" " "c" "6"))(""))
+    ((("r" "6"))("")) (((" " "r" "6"))(""))
+    ((("l" "6"))("Ƹ")) (((" " "l" "6"))(""))
+    ((("a" "6"))("")) (((" " "a" "6"))(""))
+    ((("o" "6"))("")) (((" " "o" "6"))(""))
+    ((("e" "6"))("")) (((" " "e" "6"))(""))
+    ((("u" "6"))("")) (((" " "u" "6"))(""))
+    ((("i" "6"))("")) (((" " "i" "6"))(""))
+    ((("d" "6"))("")) (((" " "d" "6"))(""))
+    ((("h" "6"))("")) (((" " "h" "6"))(""))
+    ((("t" "6"))("")) (((" " "t" "6"))(""))
+    ((("n" "6"))("")) (((" " "n" "6"))("Ŀ"))
+    ((("s" "6"))("")) (((" " "s" "6"))(""))
+    (((";" "6"))("Ȫ")) (((" " ";" "6"))(""))
+    ((("q" "6"))("")) (((" " "q" "6"))(""))
+    ((("j" "6"))("")) (((" " "j" "6"))(""))
+    ((("k" "6"))("ū")) (((" " "k" "6"))(""))
+    ((("x" "6"))("")) (((" " "x" "6"))(""))
+    ((("b" "6"))("")) (((" " "b" "6"))(""))
+    ((("m" "6"))("")) (((" " "m" "6"))(""))
+    ((("w" "6"))("")) (((" " "w" "6"))(""))
+    ((("v" "6"))("")) (((" " "v" "6"))(""))
+    ((("z" "6"))("")) (((" " "z" "6"))(""))
+    ((("/" "6"))("")) (((" " "/" "6"))(""))
+    ((("1" "7"))("")) (((" " "1" "7"))(""))
+    ((("2" "7"))("")) (((" " "2" "7"))(""))
+    ((("3" "7"))("")) (((" " "3" "7"))(""))
+    ((("4" "7"))("")) (((" " "4" "7"))(""))
+    ((("5" "7"))("")) (((" " "5" "7"))(""))
+    ((("6" "7"))("")) (((" " "6" "7"))(""))
+    ((("7" "7"))("")) (((" " "7" "7"))(""))
+    ((("8" "7"))("")) (((" " "8" "7"))(""))
+    ((("9" "7"))("")) (((" " "9" "7"))(""))
+    ((("0" "7"))("")) (((" " "0" "7"))(""))
+    ((("," "7"))("»")) (((" " "," "7"))(""))
+    ((("." "7"))("ɶ")) (((" " "." "7"))(""))
+    ((("p" "7"))("")) (((" " "p" "7"))(""))
+    ((("y" "7"))("")) (((" " "y" "7"))(""))
+    ((("f" "7"))("")) (((" " "f" "7"))(""))
+    ((("g" "7"))("æ")) (((" " "g" "7"))(""))
+    ((("c" "7"))("")) (((" " "c" "7"))(""))
+    ((("r" "7"))("")) (((" " "r" "7"))(""))
+    ((("l" "7"))("º")) (((" " "l" "7"))(""))
+    ((("a" "7"))("")) (((" " "a" "7"))(""))
+    ((("o" "7"))("")) (((" " "o" "7"))(""))
+    ((("e" "7"))("͹")) (((" " "e" "7"))(""))
+    ((("u" "7"))("")) (((" " "u" "7"))(""))
+    ((("i" "7"))("")) (((" " "i" "7"))(""))
+    ((("d" "7"))("")) (((" " "d" "7"))(""))
+    ((("h" "7"))("")) (((" " "h" "7"))(""))
+    ((("t" "7"))("")) (((" " "t" "7"))(""))
+    ((("n" "7"))("")) (((" " "n" "7"))(""))
+    ((("s" "7"))("")) (((" " "s" "7"))(""))
+    (((";" "7"))("")) (((" " ";" "7"))(""))
+    ((("q" "7"))("ü")) (((" " "q" "7"))(""))
+    ((("j" "7"))("")) (((" " "j" "7"))(""))
+    ((("k" "7"))("")) (((" " "k" "7"))(""))
+    ((("x" "7"))("")) (((" " "x" "7"))(""))
+    ((("b" "7"))("")) (((" " "b" "7"))(""))
+    ((("m" "7"))("")) (((" " "m" "7"))(""))
+    ((("w" "7"))("")) (((" " "w" "7"))(""))
+    ((("v" "7"))("")) (((" " "v" "7"))(""))
+    ((("z" "7"))("")) (((" " "z" "7"))(""))
+    ((("/" "7"))("")) (((" " "/" "7"))("м"))
     ((("1" "8"))("")) (((" " "1" "8"))(""))
     ((("2" "8"))("")) (((" " "2" "8"))(""))
     ((("3" "8"))("")) (((" " "3" "8"))(""))
@@ -353,7 +353,7 @@
     ((("w" "8"))("")) (((" " "w" "8"))(""))
     ((("v" "8"))("ε")) (((" " "v" "8"))(""))
     ((("z" "8"))("")) (((" " "z" "8"))(""))
-    ((("\057" "8"))("")) (((" " "\057" "8"))(""))
+    ((("/" "8"))("")) (((" " "/" "8"))(""))
     ((("1" "9"))("")) (((" " "1" "9"))(""))
     ((("2" "9"))("")) (((" " "2" "9"))(""))
     ((("3" "9"))("")) (((" " "3" "9"))(""))
@@ -366,7 +366,7 @@
     ((("0" "9"))("")) (((" " "0" "9"))(""))
     ((("," "9"))("Ƽ")) (((" " "," "9"))(""))
     ((("." "9"))("")) (((" " "." "9"))("ʯ"))
-    ((("p" "9"))("")) (((" " "p" "9"))(""))
+    ((("p" "9"))("Ģ")) (((" " "p" "9"))(""))
     ((("y" "9"))("")) (((" " "y" "9"))(""))
     ((("f" "9"))("")) (((" " "f" "9"))("ʺ"))
     ((("g" "9"))("")) (((" " "g" "9"))(""))
@@ -385,15 +385,15 @@
     ((("s" "9"))("")) (((" " "s" "9"))(""))
     (((";" "9"))("")) (((" " ";" "9"))(""))
     ((("q" "9"))("")) (((" " "q" "9"))(""))
-    ((("j" "9"))("")) (((" " "i" "9"))(""))
+    ((("j" "9"))("")) (((" " "j" "9"))(""))
     ((("k" "9"))("")) (((" " "k" "9"))(""))
     ((("x" "9"))("")) (((" " "x" "9"))(""))
     ((("b" "9"))("")) (((" " "b" "9"))(""))
     ((("m" "9"))("")) (((" " "m" "9"))(""))
     ((("w" "9"))("")) (((" " "w" "9"))(""))
-    ((("v" "9"))("ð")) (((" " "v" "9"))(""))
+    ((("v" "9"))("ð")) (((" " "v" "9"))("ó"))
     ((("z" "9"))("")) (((" " "z" "9"))(""))
-    ((("\057" "9"))("")) (((" " "\057" "9"))(""))
+    ((("/" "9"))("")) (((" " "/" "9"))(""))
     ((("1" "0"))("")) (((" " "1" "0"))(""))
     ((("2" "0"))("")) (((" " "2" "0"))(""))
     ((("3" "0"))("")) (((" " "3" "0"))(""))
@@ -433,7 +433,7 @@
     ((("w" "0"))("")) (((" " "w" "0"))(""))
     ((("v" "0"))("")) (((" " "v" "0"))(""))
     ((("z" "0"))("")) (((" " "z" "0"))(""))
-    ((("\057" "0"))("")) (((" " "\057" "0"))(""))
+    ((("/" "0"))("")) (((" " "/" "0"))(""))
     ((("1" ","))("α")) (((" " "1" ","))("ί"))
     ((("2" ","))("")) (((" " "2" ","))(""))
     ((("3" ","))("")) (((" " "3" ","))("Ħ"))
@@ -473,7 +473,7 @@
     ((("w" ","))("")) (((" " "w" ","))(""))
     ((("v" ","))("")) (((" " "v" ","))(""))
     ((("z" ","))("")) (((" " "z" ","))(""))
-    ((("\057" ","))("")) (((" " "\057" ","))(""))
+    ((("/" ","))("")) (((" " "/" ","))(""))
     ((("1" "."))("")) (((" " "1" "."))(""))
     ((("2" "."))("")) (((" " "2" "."))(""))
     ((("3" "."))("?")) (((" " "3" "."))(""))
@@ -513,7 +513,7 @@
     ((("w" "."))("")) (((" " "w" "."))(""))
     ((("v" "."))("")) (((" " "v" "."))(""))
     ((("z" "."))("")) (((" " "z" "."))(""))
-    ((("\057" "."))("Ϳ")) (((" " "\057" "."))(""))
+    ((("/" "."))("Ϳ")) (((" " "/" "."))(""))
     ((("1" "p"))("")) (((" " "1" "p"))(""))
     ((("2" "p"))("")) (((" " "2" "p"))(""))
     ((("3" "p"))("")) (((" " "3" "p"))(""))
@@ -553,7 +553,7 @@
     ((("w" "p"))("")) (((" " "w" "p"))("ϧ"))
     ((("v" "p"))("")) (((" " "v" "p"))(""))
     ((("z" "p"))("")) (((" " "z" "p"))(""))
-    ((("\057" "p"))("")) (((" " "\057" "p"))(""))
+    ((("/" "p"))("")) (((" " "/" "p"))(""))
     ((("1" "y"))("")) (((" " "1" "y"))(""))
     ((("2" "y"))("ħ")) (((" " "2" "y"))(""))
     ((("3" "y"))("")) (((" " "3" "y"))(""))
@@ -576,7 +576,7 @@
     ((("a" "y"))("")) (((" " "a" "y"))(""))
     ((("o" "y"))("Ϻ")) (((" " "o" "y"))("ϭ"))
     ((("e" "y"))("")) (((" " "e" "y"))(""))
-    ((("u" "y"))("ˡ")) (((" " "y" "y"))(""))
+    ((("u" "y"))("ˡ")) (((" " "u" "y"))(""))
     ((("i" "y"))("")) (((" " "i" "y"))(""))
     ((("d" "y"))("Ǥ")) (((" " "d" "y"))(""))
     ((("h" "y"))("")) (((" " "h" "y"))(""))
@@ -593,7 +593,7 @@
     ((("w" "y"))("")) (((" " "w" "y"))(""))
     ((("v" "y"))("Ψ")) (((" " "v" "y"))(""))
     ((("z" "y"))("")) (((" " "z" "y"))(""))
-    ((("\057" "y"))("")) (((" " "\057" "y"))(""))
+    ((("/" "y"))("")) (((" " "/" "y"))(""))
     ((("1" "f"))("")) (((" " "1" "f"))(""))
     ((("2" "f"))("")) (((" " "2" "f"))(""))
     ((("3" "f"))("")) (((" " "3" "f"))(""))
@@ -619,12 +619,12 @@
     ((("u" "f"))("")) (((" " "u" "f"))(""))
     ((("i" "f"))("6")) (((" " "i" "f"))(""))
     ((("d" "f"))("")) (((" " "d" "f"))(""))
-    ((("h" "f"))("")) (((" " "h" "f"))("."))
+    ((("h" "f"))("")) (((" " "h" "f"))(""))
     ((("t" "f"))("")) (((" " "t" "f"))(""))
     ((("n" "f"))("")) (((" " "n" "f"))(""))
     ((("s" "f"))("ͽ")) (((" " "s" "f"))("ͱ"))
     (((";" "f"))("2")) (((" " ";" "f"))(""))
-    ((("q" "f"))("")) (((" " "g" "f"))(""))
+    ((("q" "f"))("")) (((" " "q" "f"))(""))
     ((("j" "f"))("")) (((" " "j" "f"))(""))
     ((("k" "f"))("0")) (((" " "k" "f"))(""))
     ((("x" "f"))("")) (((" " "x" "f"))(""))
@@ -633,7 +633,7 @@
     ((("w" "f"))("")) (((" " "w" "f"))(""))
     ((("v" "f"))("")) (((" " "v" "f"))(""))
     ((("z" "f"))("")) (((" " "z" "f"))(""))
-    ((("\057" "f"))("")) (((" " "\057" "f"))(""))
+    ((("/" "f"))("")) (((" " "/" "f"))(""))
     ((("1" "g"))("")) (((" " "1" "g"))(""))
     ((("2" "g"))("")) (((" " "2" "g"))(""))
     ((("3" "g"))("")) (((" " "3" "g"))(""))
@@ -673,7 +673,7 @@
     ((("w" "g"))("")) (((" " "w" "g"))(""))
     ((("v" "g"))("")) (((" " "v" "g"))(""))
     ((("z" "g"))("ž")) (((" " "z" "g"))(""))
-    ((("\057" "g"))("")) (((" " "\057" "g"))(""))
+    ((("/" "g"))("")) (((" " "/" "g"))(""))
     ((("1" "c"))("")) (((" " "1" "c"))(""))
     ((("2" "c"))("")) (((" " "2" "c"))(""))
     ((("3" "c"))("")) (((" " "3" "c"))(""))
@@ -713,7 +713,7 @@
     ((("w" "c"))("")) (((" " "w" "c"))(""))
     ((("v" "c"))("")) (((" " "v" "c"))(""))
     ((("z" "c"))("")) (((" " "z" "c"))(""))
-    ((("\057" "c"))("")) (((" " "\057" "c"))(""))
+    ((("/" "c"))("")) (((" " "/" "c"))(""))
     ((("1" "r"))("")) (((" " "1" "r"))(""))
     ((("2" "r"))("")) (((" " "2" "r"))("ʽ"))
     ((("3" "r"))("")) (((" " "3" "r"))(""))
@@ -753,7 +753,7 @@
     ((("w" "r"))("")) (((" " "w" "r"))(""))
     ((("v" "r"))("")) (((" " "v" "r"))(""))
     ((("z" "r"))("Ŭ")) (((" " "z" "r"))(""))
-    ((("\057" "r"))("")) (((" " "\057" "r"))(""))
+    ((("/" "r"))("")) (((" " "/" "r"))(""))
     ((("1" "l"))("")) (((" " "1" "l"))(""))
     ((("2" "l"))("")) (((" " "2" "l"))(""))
     ((("3" "l"))("̴")) (((" " "3" "l"))("ѳ"))
@@ -786,14 +786,14 @@
     (((";" "l"))("ʸ")) (((" " ";" "l"))(""))
     ((("q" "l"))("")) (((" " "q" "l"))(""))
     ((("j" "l"))("")) (((" " "j" "l"))("¥"))
-    ((("k" "l"))("ŷ")) (((" " "k" "l"))("ŷ"))
+    ((("k" "l"))("ŷ")) (((" " "k" "l"))(""))
     ((("x" "l"))("")) (((" " "x" "l"))(""))
     ((("b" "l"))("")) (((" " "b" "l"))("ķ"))
     ((("m" "l"))("")) (((" " "m" "l"))(""))
     ((("w" "l"))("")) (((" " "w" "l"))(""))
     ((("v" "l"))("")) (((" " "v" "l"))(""))
     ((("z" "l"))("")) (((" " "z" "l"))(""))
-    ((("\057" "l"))("")) (((" " "\057" "l"))(""))
+    ((("/" "l"))("")) (((" " "/" "l"))(""))
     ((("1" "a"))("")) (((" " "1" "a"))(""))
     ((("2" "a"))("")) (((" " "2" "a"))("Ϯ"))
     ((("3" "a"))("")) (((" " "3" "a"))(""))
@@ -833,7 +833,7 @@
     ((("w" "a"))("")) (((" " "w" "a"))(""))
     ((("v" "a"))("")) (((" " "v" "a"))(""))
     ((("z" "a"))("")) (((" " "z" "a"))(""))
-    ((("\057" "a"))("")) (((" " "\057" "a"))(""))
+    ((("/" "a"))("")) (((" " "/" "a"))(""))
     ((("1" "o"))("")) (((" " "1" "o"))(""))
     ((("2" "o"))("Ǽ")) (((" " "2" "o"))(""))
     ((("3" "o"))("")) (((" " "3" "o"))(""))
@@ -873,7 +873,7 @@
     ((("w" "o"))("")) (((" " "w" "o"))(""))
     ((("v" "o"))("")) (((" " "v" "o"))(""))
     ((("z" "o"))("")) (((" " "z" "o"))(""))
-    ((("\057" "o"))("")) (((" " "\057" "o"))(""))
+    ((("/" "o"))("")) (((" " "/" "o"))(""))
     ((("1" "e"))("")) (((" " "1" "e"))(""))
     ((("2" "e"))("")) (((" " "2" "e"))(""))
     ((("3" "e"))("")) (((" " "3" "e"))(""))
@@ -913,7 +913,7 @@
     ((("w" "e"))("")) (((" " "w" "e"))(""))
     ((("v" "e"))("")) (((" " "v" "e"))(""))
     ((("z" "e"))("")) (((" " "z" "e"))(""))
-    ((("\057" "e"))("")) (((" " "\057" "e"))("į"))
+    ((("/" "e"))("")) (((" " "/" "e"))("į"))
     ((("1" "u"))("")) (((" " "1" "u"))(""))
     ((("2" "u"))("")) (((" " "2" "u"))(""))
     ((("3" "u"))("")) (((" " "3" "u"))(""))
@@ -953,7 +953,7 @@
     ((("w" "u"))("")) (((" " "w" "u"))(""))
     ((("v" "u"))("")) (((" " "v" "u"))(""))
     ((("z" "u"))("")) (((" " "z" "u"))("Ī"))
-    ((("\057" "u"))("")) (((" " "\057" "u"))(""))
+    ((("/" "u"))("")) (((" " "/" "u"))(""))
     ((("1" "i"))("")) (((" " "1" "i"))(""))
     ((("2" "i"))("")) (((" " "2" "i"))(""))
     ((("3" "i"))("")) (((" " "3" "i"))(""))
@@ -993,7 +993,7 @@
     ((("w" "i"))("")) (((" " "w" "i"))("Ͷ"))
     ((("v" "i"))("")) (((" " "v" "i"))(""))
     ((("z" "i"))("")) (((" " "z" "i"))(""))
-    ((("\057" "i"))("Ư")) (((" " "\057" "i"))(""))
+    ((("/" "i"))("Ư")) (((" " "/" "i"))(""))
     ((("1" "d"))("")) (((" " "1" "d"))(""))
     ((("2" "d"))("")) (((" " "2" "d"))(""))
     ((("3" "d"))("")) (((" " "3" "d"))(""))
@@ -1025,7 +1025,7 @@
     ((("s" "d"))("")) (((" " "s" "d"))(""))
     (((";" "d"))("1")) (((" " ";" "d"))(""))
     ((("q" "d"))("")) (((" " "q" "d"))(""))
-    ((("j" "d"))("")) (((" " "j" "d"))(","))
+    ((("j" "d"))("")) (((" " "j" "d"))(""))
     ((("k" "d"))("")) (((" " "k" "d"))(""))
     ((("x" "d"))("")) (((" " "x" "d"))(""))
     ((("b" "d"))("")) (((" " "b" "d"))(""))
@@ -1033,7 +1033,7 @@
     ((("w" "d"))("")) (((" " "w" "d"))(""))
     ((("v" "d"))("Ⱦ")) (((" " "v" "d"))("ȼ"))
     ((("z" "d"))("")) (((" " "z" "d"))(""))
-    ((("\057" "d"))("")) (((" " "\057" "d"))("ɤ"))
+    ((("/" "d"))("")) (((" " "/" "d"))("ɤ"))
     ((("1" "h"))("")) (((" " "1" "h"))(""))
     ((("2" "h"))("")) (((" " "2" "h"))(""))
     ((("3" "h"))("")) (((" " "3" "h"))(""))
@@ -1073,7 +1073,7 @@
     ((("w" "h"))("")) (((" " "w" "h"))(""))
     ((("v" "h"))("")) (((" " "v" "h"))(""))
     ((("z" "h"))("")) (((" " "z" "h"))(""))
-    ((("\057" "h"))("")) (((" " "\057" "h"))(""))
+    ((("/" "h"))("")) (((" " "/" "h"))(""))
     ((("1" "t"))("")) (((" " "1" "t"))(""))
     ((("2" "t"))("")) (((" " "2" "t"))(""))
     ((("3" "t"))("")) (((" " "3" "t"))(""))
@@ -1107,13 +1107,13 @@
     ((("q" "t"))("")) (((" " "q" "t"))(""))
     ((("j" "t"))("")) (((" " "j" "t"))(""))
     ((("k" "t"))("8")) (((" " "k" "t"))("˪"))
-    ((("x" "t"))("")) (((" " "" "t"))(""))
-    ((("b" "t"))("")) (((" " "x" "t"))(""))
+    ((("x" "t"))("")) (((" " "x" "t"))(""))
+    ((("b" "t"))("")) (((" " "b" "t"))(""))
     ((("m" "t"))("")) (((" " "m" "t"))(""))
     ((("w" "t"))("")) (((" " "w" "t"))(""))
     ((("v" "t"))("")) (((" " "v" "t"))(""))
     ((("z" "t"))("")) (((" " "z" "t"))(""))
-    ((("\057" "t"))("")) (((" " "\057" "t"))(""))
+    ((("/" "t"))("")) (((" " "/" "t"))(""))
     ((("1" "n"))("")) (((" " "1" "n"))(""))
     ((("2" "n"))("")) (((" " "2" "n"))(""))
     ((("3" "n"))("")) (((" " "3" "n"))(""))
@@ -1153,7 +1153,7 @@
     ((("w" "n"))("ģ")) (((" " "w" "n"))(""))
     ((("v" "n"))("")) (((" " "v" "n"))(""))
     ((("z" "n"))("")) (((" " "z" "n"))(""))
-    ((("\057" "n"))("")) (((" " "\057" "n"))(""))
+    ((("/" "n"))("")) (((" " "/" "n"))(""))
     ((("1" "s"))("")) (((" " "1" "s"))(""))
     ((("2" "s"))("")) (((" " "2" "s"))(""))
     ((("3" "s"))("")) (((" " "3" "s"))(""))
@@ -1193,7 +1193,7 @@
     ((("w" "s"))("ͺ")) (((" " "w" "s"))(""))
     ((("v" "s"))("")) (((" " "v" "s"))(""))
     ((("z" "s"))("")) (((" " "z" "s"))(""))
-    ((("\057" "s"))("")) (((" " "\057" "s"))(""))
+    ((("/" "s"))("")) (((" " "/" "s"))(""))
     ((("1" ";"))("")) (((" " "1" ";"))(""))
     ((("2" ";"))("")) (((" " "2" ";"))(""))
     ((("3" ";"))("")) (((" " "3" ";"))(""))
@@ -1233,7 +1233,7 @@
     ((("w" ";"))("")) (((" " "w" ";"))(""))
     ((("v" ";"))("")) (((" " "v" ";"))(""))
     ((("z" ";"))("")) (((" " "z" ";"))(""))
-    ((("\057" ";"))("")) (((" " "\057" ";"))(""))
+    ((("/" ";"))("")) (((" " "/" ";"))(""))
     ((("1" "q"))("")) (((" " "1" "q"))(""))
     ((("2" "q"))("")) (((" " "2" "q"))(""))
     ((("3" "q"))("")) (((" " "3" "q"))(""))
@@ -1273,7 +1273,7 @@
     ((("w" "q"))("")) (((" " "w" "q"))(""))
     ((("v" "q"))("")) (((" " "v" "q"))(""))
     ((("z" "q"))("")) (((" " "z" "q"))(""))
-    ((("\057" "q"))("")) (((" " "\057" "q"))(""))
+    ((("/" "q"))("")) (((" " "/" "q"))(""))
     ((("1" "j"))("")) (((" " "1" "j"))(""))
     ((("2" "j"))("")) (((" " "2" "j"))(""))
     ((("3" "j"))("")) (((" " "3" "j"))("ϼ"))
@@ -1313,7 +1313,7 @@
     ((("w" "j"))("ĥ")) (((" " "w" "j"))("ı"))
     ((("v" "j"))("")) (((" " "v" "j"))(""))
     ((("z" "j"))("")) (((" " "z" "j"))("ȱ"))
-    ((("\057" "j"))("")) (((" " "\057" "j"))(""))
+    ((("/" "j"))("")) (((" " "/" "j"))(""))
     ((("1" "k"))("")) (((" " "1" "k"))(""))
     ((("2" "k"))("")) (((" " "2" "k"))(""))
     ((("3" "k"))("")) (((" " "3" "k"))(""))
@@ -1353,7 +1353,7 @@
     ((("w" "k"))("")) (((" " "w" "k"))(""))
     ((("v" "k"))("")) (((" " "v" "k"))(""))
     ((("z" "k"))("")) (((" " "z" "k"))(""))
-    ((("\057" "k"))("")) (((" " "\057" "k"))(""))
+    ((("/" "k"))("")) (((" " "/" "k"))(""))
     ((("1" "x"))("")) (((" " "1" "x"))(""))
     ((("2" "x"))("ɲ")) (((" " "2" "x"))("ɱ"))
     ((("3" "x"))("")) (((" " "3" "x"))(""))
@@ -1393,7 +1393,7 @@
     ((("w" "x"))("")) (((" " "w" "x"))(""))
     ((("v" "x"))("")) (((" " "v" "x"))(""))
     ((("z" "x"))("Ƚ")) (((" " "z" "x"))(""))
-    ((("\057" "x"))("")) (((" " "\057" "x"))(""))
+    ((("/" "x"))("")) (((" " "/" "x"))(""))
     ((("1" "b"))("")) (((" " "1" "b"))(""))
     ((("2" "b"))("")) (((" " "2" "b"))(""))
     ((("3" "b"))("Χ")) (((" " "3" "b"))(""))
@@ -1433,7 +1433,7 @@
     ((("w" "b"))("")) (((" " "w" "b"))("ǫ"))
     ((("v" "b"))("ʡ")) (((" " "v" "b"))(""))
     ((("z" "b"))("")) (((" " "z" "b"))(""))
-    ((("\057" "b"))("")) (((" " "\057" "b"))(""))
+    ((("/" "b"))("")) (((" " "/" "b"))(""))
     ((("1" "m"))("")) (((" " "1" "m"))("ɯ"))
     ((("2" "m"))("")) (((" " "2" "m"))(""))
     ((("3" "m"))("")) (((" " "3" "m"))(""))
@@ -1473,7 +1473,7 @@
     ((("w" "m"))("")) (((" " "w" "m"))(""))
     ((("v" "m"))("")) (((" " "v" "m"))(""))
     ((("z" "m"))("Ƿ")) (((" " "z" "m"))("˳"))
-    ((("\057" "m"))("")) (((" " "\057" "m"))(""))
+    ((("/" "m"))("")) (((" " "/" "m"))(""))
     ((("1" "w"))("")) (((" " "1" "w"))(""))
     ((("2" "w"))("")) (((" " "2" "w"))(""))
     ((("3" "w"))("")) (((" " "3" "w"))(""))
@@ -1513,7 +1513,7 @@
     ((("w" "w"))("")) (((" " "w" "w"))(""))
     ((("v" "w"))("")) (((" " "v" "w"))(""))
     ((("z" "w"))("")) (((" " "z" "w"))(""))
-    ((("\057" "w"))("")) (((" " "\057" "w"))(""))
+    ((("/" "w"))("")) (((" " "/" "w"))(""))
     ((("1" "v"))("")) (((" " "1" "v"))(""))
     ((("2" "v"))("")) (((" " "2" "v"))(""))
     ((("3" "v"))("")) (((" " "3" "v"))(""))
@@ -1534,7 +1534,7 @@
     ((("r" "v"))("")) (((" " "r" "v"))(""))
     ((("l" "v"))("")) (((" " "l" "v"))("˦"))
     ((("a" "v"))("")) (((" " "a" "v"))("̻"))
-    ((("o" "v"))("")) (((" " "o" "v"))(""))
+    ((("o" "v"))("")) (((" " "o" "v"))("ǣ"))
     ((("e" "v"))("")) (((" " "e" "v"))(""))
     ((("u" "v"))("")) (((" " "u" "v"))(""))
     ((("i" "v"))("")) (((" " "i" "v"))(""))
@@ -1553,7 +1553,7 @@
     ((("w" "v"))("")) (((" " "w" "v"))(""))
     ((("v" "v"))("")) (((" " "v" "v"))("ĵ"))
     ((("z" "v"))("")) (((" " "z" "v"))(""))
-    ((("\057" "v"))("")) (((" " "\057" "v"))(""))
+    ((("/" "v"))("")) (((" " "/" "v"))(""))
     ((("1" "z"))("")) (((" " "1" "z"))(""))
     ((("2" "z"))("")) (((" " "2" "z"))(""))
     ((("3" "z"))("")) (((" " "3" "z"))(""))
@@ -1593,47 +1593,47 @@
     ((("w" "z"))("")) (((" " "w" "z"))(""))
     ((("v" "z"))("")) (((" " "v" "z"))(""))
     ((("z" "z"))("")) (((" " "z" "z"))(""))
-    ((("\057" "z"))("")) (((" " "\057" "z"))(""))
-    ((("1" "\057"))("")) (((" " "1" "\057"))(""))
-    ((("2" "\057"))("")) (((" " "2" "\057"))("ų"))
-    ((("3" "\057"))("")) (((" " "3" "\057"))("Ǵ"))
-    ((("4" "\057"))("Ȣ")) (((" " "4" "\057"))("ê"))
-    ((("5" "\057"))("")) (((" " "5" "\057"))(""))
-    ((("6" "\057"))("")) (((" " "6" "\057"))(""))
-    ((("7" "\057"))("")) (((" " "7" "\057"))(""))
-    ((("8" "\057"))("Ĳ")) (((" " "8" "\057"))(""))
-    ((("9" "\057"))("ʴ")) (((" " "9" "\057"))("ʶ"))
-    ((("0" "\057"))("")) (((" " "0" "\057"))(""))
-    ((("," "\057"))("")) (((" " "," "\057"))(""))
-    ((("." "\057"))("ȿ")) (((" " "." "\057"))(""))
-    ((("p" "\057"))("")) (((" " "p" "\057"))(""))
-    ((("y" "\057"))("ô")) (((" " "y" "\057"))("â"))
-    ((("f" "\057"))("")) (((" " "f" "\057"))("ţ"))
-    ((("g" "\057"))("Ʋ")) (((" " "g" "\057"))(""))
-    ((("c" "\057"))("")) (((" " "c" "\057"))(""))
-    ((("r" "\057"))("")) (((" " "r" "\057"))(""))
-    ((("l" "\057"))("")) (((" " "l" "\057"))(""))
-    ((("a" "\057"))("")) (((" " "a" "\057"))(""))
-    ((("o" "\057"))("")) (((" " "o" "\057"))(""))
-    ((("e" "\057"))("")) (((" " "e" "\057"))(""))
-    ((("u" "\057"))("Φ")) (((" " "u" "\057"))("δ"))
-    ((("i" "\057"))("")) (((" " "i" "\057"))(""))
-    ((("d" "\057"))("")) (((" " "d" "\057"))(""))
-    ((("h" "\057"))("")) (((" " "h" "\057"))(""))
-    ((("t" "\057"))("")) (((" " "t" "\057"))(""))
-    ((("n" "\057"))("")) (((" " "n" "\057"))(""))
-    ((("s" "\057"))("")) (((" " "s" "\057"))(""))
-    (((";" "\057"))("")) (((" " ";" "\057"))(""))
-    ((("q" "\057"))("")) (((" " "q" "\057"))(""))
-    ((("j" "\057"))("")) (((" " "j" "\057"))(""))
-    ((("k" "\057"))("")) (((" " "k" "\057"))(""))
-    ((("x" "\057"))("")) (((" " "x" "\057"))(""))
-    ((("b" "\057"))("ñ")) (((" " "b" "\057"))(""))
-    ((("m" "\057"))("")) (((" " "m" "\057"))(""))
-    ((("w" "\057"))("ȴ")) (((" " "w" "\057"))(""))
-    ((("v" "\057"))("")) (((" " "v" "\057"))(""))
-    ((("z" "\057"))("")) (((" " "z" "\057"))(""))
-    ((("\057" "\057"))("")) (((" " "\057" "\057"))(""))
+    ((("/" "z"))("")) (((" " "/" "z"))(""))
+    ((("1" "/"))("")) (((" " "1" "/"))(""))
+    ((("2" "/"))("")) (((" " "2" "/"))("ų"))
+    ((("3" "/"))("")) (((" " "3" "/"))("Ǵ"))
+    ((("4" "/"))("Ȣ")) (((" " "4" "/"))("ê"))
+    ((("5" "/"))("")) (((" " "5" "/"))(""))
+    ((("6" "/"))("")) (((" " "6" "/"))(""))
+    ((("7" "/"))("")) (((" " "7" "/"))(""))
+    ((("8" "/"))("Ĳ")) (((" " "8" "/"))(""))
+    ((("9" "/"))("ʴ")) (((" " "9" "/"))("ʶ"))
+    ((("0" "/"))("")) (((" " "0" "/"))(""))
+    ((("," "/"))("")) (((" " "," "/"))(""))
+    ((("." "/"))("ȿ")) (((" " "." "/"))(""))
+    ((("p" "/"))("")) (((" " "p" "/"))(""))
+    ((("y" "/"))("ô")) (((" " "y" "/"))("â"))
+    ((("f" "/"))("")) (((" " "f" "/"))("ţ"))
+    ((("g" "/"))("Ʋ")) (((" " "g" "/"))(""))
+    ((("c" "/"))("")) (((" " "c" "/"))(""))
+    ((("r" "/"))("")) (((" " "r" "/"))(""))
+    ((("l" "/"))("")) (((" " "l" "/"))(""))
+    ((("a" "/"))("")) (((" " "a" "/"))(""))
+    ((("o" "/"))("")) (((" " "o" "/"))(""))
+    ((("e" "/"))("")) (((" " "e" "/"))(""))
+    ((("u" "/"))("Φ")) (((" " "u" "/"))("δ"))
+    ((("i" "/"))("")) (((" " "i" "/"))(""))
+    ((("d" "/"))("")) (((" " "d" "/"))(""))
+    ((("h" "/"))("")) (((" " "h" "/"))(""))
+    ((("t" "/"))("")) (((" " "t" "/"))(""))
+    ((("n" "/"))("")) (((" " "n" "/"))(""))
+    ((("s" "/"))("")) (((" " "s" "/"))(""))
+    (((";" "/"))("")) (((" " ";" "/"))(""))
+    ((("q" "/"))("")) (((" " "q" "/"))(""))
+    ((("j" "/"))("")) (((" " "j" "/"))(""))
+    ((("k" "/"))("")) (((" " "k" "/"))(""))
+    ((("x" "/"))("")) (((" " "x" "/"))(""))
+    ((("b" "/"))("ñ")) (((" " "b" "/"))(""))
+    ((("m" "/"))("")) (((" " "m" "/"))(""))
+    ((("w" "/"))("ȴ")) (((" " "w" "/"))(""))
+    ((("v" "/"))("")) (((" " "v" "/"))(""))
+    ((("z" "/"))("")) (((" " "z" "/"))(""))
+    ((("/" "/"))("")) (((" " "/" "/"))(""))
     (((" " " "))(" "))))
 
 (define trycode-init-handler
